@@ -4,9 +4,9 @@ from pydantic import BaseModel, Extra
 
 
 class Discriminator(BaseModel):
-    """
-    When request bodies or response payloads may be one of a number of different schemas,
-    a `discriminator` object can be used to aid in serialization, deserialization, and validation.
+    """When request bodies or response payloads may be one of a number of
+    different schemas, a `discriminator` object can be used to aid in
+    serialization, deserialization, and validation.
 
     The discriminator is a specific object in a schema which is used to inform the consumer of the specification
     of an alternative schema based on the value associated with it.
